// tux avatar
unsigned char tux_img[59*74*3] = {
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,   36,   36,   36,   74,   74,   76,   44,   44,   44,    2,    2, 
   4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,   36,   36,   36,  124,  124,  124,   86,   86,   84,   28, 
  28,   27,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,   44,   44,   44,   92,   92,   92,   60,   60,   60, 
  36,   36,   36,   10,    6,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,   20,   20,   19,   10,    6,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,   12,   12,   12, 
  10,    6,    4,   44,   44,   44,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,   52,   52, 
  52,   20,   20,   19,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,   20,   20, 
  19,  131,  131,  132,    2,    2,    4,   52,   52,   52,    2,    2,    4,    2,    2,    4, 
  12,   12,   12,    2,    2,    4,   86,   86,   84,  141,  141,  140,  156,  156,  156,   68, 
  68,   68,   12,   12,   12,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,  148, 
 148,  148,  204,  204,  204,  156,  156,  156,   20,   20,   19,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,  100,  100,  100,  172,  172,  172,  196,  196,  196,  204,  204,  204, 
 181,  180,  179,   28,   28,   27,   12,   12,   12,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,   10,    6,    4, 
 244,  244,  244,  254,  254,  252,  254,  254,  252,  228,  228,  228,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,  221,  221,  220,  254,  254,  252,  228,  228,  228,  212,  212, 
 212,  244,  244,  244,  164,  164,  164,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,   60,   60, 
  60,  124,  124,  124,   60,   60,   60,  148,  148,  148,  254,  254,  252,   12,   12,   12, 
  12,   12,   12,    2,    2,    4,  244,  244,  244,  244,  244,  244,    2,    2,    4,  148, 
 148,  148,  212,  212,  212,  254,  254,  252,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,   86, 
  86,   84,    2,    2,    4,    2,    2,    4,   44,   44,   44,  254,  254,  252,   12,   12, 
  12,   12,   12,   12,   12,   12,   12,  236,  236,  236,   36,   36,   36,    2,    2,    4, 
  12,   12,   12,   12,   12,   12,  254,  254,  252,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4, 
  52,   52,   52,   12,   12,   12,    2,    2,    4,    2,    2,    4,  164,  164,  164,  182, 
 140,    8,  172,  140,    4,  142,  106,    7,  156,  156,  156,   60,   60,   60,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,  254,  254,  252,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2, 
   4,    2,    2,    4,  254,  254,  252,    2,    2,    4,  173,  120,   10,  173,  120,   10, 
 235,  188,   11,  225,  180,   10,  142,  106,    7,  225,  180,   10,  225,  180,   10,    2, 
   2,    4,    2,    2,    4,  254,  254,  252,  254,  254,  252,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2, 
   2,    4,    2,    2,    4,  228,  228,  228,  173,  120,   10,  218,  163,    9,  236,  180, 
  11,  235,  188,   11,  235,  196,   12,  235,  205,   40,  244,  213,   67,  241,  212,   42, 
 243,  196,   11,  215,  172,    9,  196,  196,  196,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
   2,    2,    4,    2,    2,    4,  165,  114,   10,  201,  142,    7,  229,  172,    9,  236, 
 180,   11,  235,  196,   12,  237,  204,   14,  242,  218,   44,  246,  218,   74,  246,  218, 
  20,  246,  213,   13,  246,  218,   20,  243,  205,   12,  235,  179,   22,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,    2,    2,    4,   73,   48,    6,  192,  133,    7,  216,  156,    8,  236,  180,   11, 
 235,  188,   11,  235,  196,   12,  235,  205,   40,  246,  218,   74,  246,  218,   20,  246, 
 218,   20,  246,  213,   13,  246,  213,   13,  150,  114,   11,  229,  172,    9,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,    2,    2,    4,  106,   75,    6,  201,  142,    7,  223,  165,    9,  242,  182, 
  12,  235,  188,   11,  237,  204,   14,  244,  213,   67,  246,  218,   20,  246,  213,   13, 
 246,  213,   13,  208,  164,   13,  206,  142,    8,  218,  163,    9,  216,  156,    8,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,    2,    2,    4,    2,    2,    4,  116,   73,    4,  215,  172,    9,  245, 
 189,   12,  235,  196,   12,  235,  205,   40,  241,  211,   17,  246,  213,   13,  237,  204, 
  14,  106,   75,    6,  207,  148,    7,  216,  156,    8,  216,  156,    8,  199,  138,    8, 
   2,    2,    4,    2,    2,    4,  124,  124,  124,   28,   28,   27,    2,    2,    4,    2, 
   2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,    2,    2,    4,    2,    2,    4,  164,  164,  164,  136,   95,    7, 
 142,  106,    7,  189,  157,    4,  189,  157,    4,  154,  119,   11,  164,  109,    5,  192, 
 133,    7,  206,  142,    8,  207,  148,    7,  192,  133,    7,  190,  189,  188,  190,  189, 
 188,    2,    2,    4,    2,    2,    4,   36,   36,   36,  131,  131,  132,   52,   52,   52, 
   2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,  190,  189,  188,  190,  189, 
 188,  155,  102,    5,  193,  139,   10,  223,  165,    9,  215,  150,   13,  206,  142,    8, 
 192,  133,    7,  192,  133,    7,  184,  173,  150,  190,  189,  188,  196,  196,  196,  196, 
 196,  196,   28,   28,   27,    2,    2,    4,    2,    2,    4,  124,  124,  124,   74,   74, 
  76,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,  190,  189,  188,  190, 
 189,  188,  190,  189,  188,  144,   96,    7,  164,  109,    5,  164,  109,    5,  155,  102, 
   5,  171,  114,    5,  190,  189,  188,  181,  180,  179,  196,  196,  196,  244,  244,  244, 
 244,  244,  244,  212,  212,  212,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4,  236,  236,  236, 
 204,  204,  204,  190,  189,  188,  190,  189,  188,  181,  180,  179,  184,  173,  150,  190, 
 189,  188,  190,  189,  188,  190,  189,  188,  204,  204,  204,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,   28,   28,   27,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,   12,   12,   12,    2,    2,    4,  108,  108,  107,  254,  254, 
 252,  236,  236,  236,  190,  189,  188,  190,  189,  188,  190,  189,  188,  190,  189,  188, 
 190,  189,  188,  190,  189,  188,  212,  212,  212,  244,  244,  244,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,    2,    2,    4,   12,   12,   12,   20,   20,   19,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  204,  204,  204,  190,  189,  188,  190,  189,  188,  190,  189, 
 188,  212,  212,  212,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,   10,    6,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,    2,    2,    4,    2,    2,    4,    2,    2,    4,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  236,  236,  236,  228,  228,  228,  244, 
 244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  236,  236,  236, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,    2,    2,    4,    2,    2,    4,    2,    2,    4,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244, 
 244,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  164,  164,  164,  244,  244,  244, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252,  236, 
 236,  236,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  236,  236,  236,  221,  221,  220, 
 228,  228,  228,   52,   52,   52,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,   12,   12,   12,  156,  156,  156,  196,  196, 
 196,  228,  228,  228,  244,  244,  244,  244,  244,  244,  244,  244,  244,  228,  228,  228, 
 228,  228,  228,  236,  236,  236,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  212,  212,  212,  204,  204,  204,  196,  196,  196,  196,  196,  196,  190,  189, 
 188,  196,  196,  196,  244,  244,  244,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,   20,   20,   19,  172,  172,  172,  228, 
 228,  228,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  236,  236, 
 236,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  236,  236,  236,  221,  221,  220,  204,  204,  204,  196, 
 196,  196,  190,  189,  188,  204,  204,  204,  100,  100,  100,    2,    2,    4,   60,   60, 
  60,   36,   36,   36,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2, 
   4,    2,    2,    4,   12,   12,   12,    2,    2,    4,  164,  164,  164,  228,  228,  228, 
 254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 244,  244,  244,  212,  212,  212,  190,  189,  188,  244,  244,  244,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,   52,   52,   52,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,   80,   80,   80,    2,    2,    4,    2,    2,    4,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  236,  236,  236,  196,  196,  196,  254,  254,  252, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,   68,   68,   68,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4, 
   2,    2,    4,   12,   12,   12,    2,    2,    4,  181,  180,  179,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  221,  221,  220,  212,  212, 
 212,    2,    2,    4,   12,   12,   12,   44,   44,   44,   12,   12,   12,   10,    6,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2, 
   4,   80,   80,   80,    2,    2,    4,    2,    2,    4,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,   44,   44,   44,   20,   20,   19,   80,   80,   80,   28,   28,   27,   80,   80, 
  80,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,   10,    6,    4,    2,    2,    4,  204,  204,  204,  254,  254,  252,  244,  244, 
 244,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  244,  244,  244,   20,   20,   19,   28,   28,   27,   12,   12,   12,   12, 
  12,   12,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4, 
  12,   12,   12,    2,    2,    4,    2,    2,    4,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  228,  228,  228,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  244,  244,  244,  244,  244,  244,  254,  254,  252,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,   36,   36,   36,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2, 
   4,  100,  100,  100,    2,    2,    4,   28,   28,   27,  254,  254,  252,  254,  254,  252, 
 244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  228,  228,  228,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  254,  254,  252,  254,  254,  252,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,   80,   80,   80,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,   10,    6,    4,    2,    2,    4,  228,  228,  228,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  221,  221,  220,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244, 
 254,  254,  252,  244,  244,  244,  254,  254,  252,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,   80,   80,   80,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4, 
  10,    6,    4,    2,    2,    4,    2,    2,    4,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  221,  221,  220,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,   10,    6,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,   44,   44,   44,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2, 
   4,   20,   20,   19,    2,    2,    4,   20,   20,   19,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  221,  221,  220,  244,  244,  244,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252,   36,   36,   36,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,   28,   28,   27,    2,    2,    4,   28,   28,   27,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244, 
 254,  254,  252,  254,  254,  252,  221,  221,  220,  254,  254,  252,  244,  244,  244,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,   60,   60,   60,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,   60,   60,   60,    2,    2,    4,   60,   60,   60,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  244,  244,  244,  254,  254,  252,  228,  228,  228,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,   68,   68,   68, 
   2,    2,    4,    2,    2,    4,   68,   68,   68,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,   20,   20,   19,   36,   36,   36,  100,  100,  100,  254,  254,  252, 
 254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  254,  254,  252,  254,  254,  252,  228,  228,  228,  254,  254,  252,  254,  254, 
 252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,   60,   60, 
  60,    2,    2,    4,    2,    2,    4,   20,   20,   19,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,   12,   12,   12,   92,   92,   92,  244,  244, 
 244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  228,  228,  228,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  244,  244,  244,  244,  244,  244,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  244,  244,  244,    2, 
   2,    4,   12,   12,   12,   60,   60,   60,   10,    6,    4,   36,   36,   36,   44,   44, 
  44,   12,   12,   12,    2,    2,    4,    2,    2,    4,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 207,  148,    7,  245,  189,   12,  223,  165,    9,    2,    2,    4,   80,   80,   80,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  228,  228,  228,  254,  254,  252, 
 244,  244,  244,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,  124,  124,  124,    2,    2,    4,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  193,  139, 
  10,  242,  182,   12,  245,  189,   12,  245,  189,   12,  229,  172,    9,    2,    2,    4, 
  68,   68,   68,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  228,  228,  228,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  223,  172,   66,  236,  180,   11,  235,  179, 
  22,  126,   98,   12,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,   60,   60,   60,   28,   28,   27,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  215, 
 150,   13,  235,  179,   22,  245,  189,   12,  245,  189,   12,  245,  189,   12,  165,  114, 
  10,    2,    2,    4,  108,  108,  107,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  228,  228,  228,  254, 
 254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  229,  172,    9,  243,  196,   11,  246, 
 213,   13,  148,  108,    9,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,   20,   20,   19,   20,   20,   19,  164,  119,   10,  226,  188,   12, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  199,  138,    8, 
 223,  165,    9,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  145,  102,   10,    2,    2,    4,   20,   20,   19,  244,  244,  244,  254,  254, 
 252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  236,  236,  236, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  223,  165,    9,  245,  189,   12, 
 226,  188,   12,   92,   67,    9,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,   20,   20,   19,  235,  196,   12,  243,  205, 
  12,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  182, 
 126,   10,  216,  156,    8,  218,  163,    9,  209,  155,    9,  207,  148,    7,  229,  172, 
   9,  236,  180,   11,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  237,  204,   14,    2,    2,    4,    2,    2,    4,   10,    6,    4,  228, 
 228,  228,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  254,  254,  252,  244,  244,  244,  221,  221,  220,  223,  165,    9,  242,  182, 
  12,  229,  172,    9,  173,  120,   10,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,  223,  165,    9,  235,  188,   11,  245, 
 189,   12,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 215,  150,   13,  235,  179,   22,  236,  180,   11,  229,  172,    9,  236,  180,   11,  242, 
 182,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  243,  196,   11,  170,  126,   10,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,  236,  236,  236,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244, 
 244,  254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  204,  204,  204,  196,  196,  196,  216,  156,    8,  236, 
 180,   11,  223,  165,    9,  185,  131,    9,   73,   48,    6,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,   41,   28,    4,  185,  131,    9,  229,  172,    9,  235,  188,   11, 
 245,  189,   12,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  181,  126, 
  47,  218,  163,    9,  236,  180,   11,  242,  182,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  226,  188,   12,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,   12,   12,   12,  181,  180,  179,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  196,  196,  196,  196,  196,  196,  215,  150,   13, 
 229,  172,    9,  229,  172,    9,  207,  148,    7,  185,  131,    9,  179,  121,    7,  173, 
 120,   10,  179,  121,    7,  192,  133,    7,  216,  156,    8,  242,  182,   12,  245,  189, 
  12,  245,  189,   12,  215,  172,    9,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  218,  163,    9,  242,  182,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  243,  196,   11,  194,  147,   11,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,  244,  244,  244,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244, 
 244,  244,  254,  254,  252,  254,  254,  252,  204,  204,  204,  196,  196,  196,  201,  142, 
   7,  229,  172,    9,  236,  180,   11,  218,  163,    9,  207,  148,    7,  207,  148,    7, 
 207,  148,    7,  207,  148,    7,  223,  165,    9,  236,  180,   11,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  242,  182,   12,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  216,  156,    8,  235,  179,   22,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  243,  205,   12, 
  20,   20,   19,    2,    2,    4,    2,    2,    4,    2,    2,    4,   12,   12,   12,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  221,  221,  220,  196,  196,  196,  185, 
 131,    9,  223,  165,    9,  242,  182,   12,  236,  180,   11,  223,  165,    9,  223,  165, 
   9,  223,  165,    9,  229,  172,    9,  236,  180,   11,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  242,  182,   12,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  207,  148,   24,  236,  180,   11,  242,  182,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  216,  156,    8,    2,    2,    4,    2,    2,    4,    2,    2,    4,   12,   12,   12, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  228,  228,  228,  190,  189,  188, 
 185,  131,    9,  223,  165,    9,  242,  182,   12,  245,  189,   12,  236,  180,   11,  236, 
 180,   11,  236,  180,   11,  242,  182,   12,  245,  189,   12,  242,  182,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  242,  182,   12,  235,  188,   11, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  206,  142,    8,  235,  179,   22,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  243,  205,   12,  164,  119,   10,    2,    2,    4,    2,    2,    4,  244,  244, 
 244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  190,  189,  188,    2,    2, 
   4,  185,  131,    9,  223,  165,    9,  235,  188,   11,  242,  182,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  242,  182,   12,  229,  172,    9,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  206,  142,    8,  229,  172,    9,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  235,  188,   11,  235,  196,   12,  236,  236,  236,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  236,  236,  236,    2,    2,    4,   10, 
   6,    4,  185,  131,    9,  223,  165,    9,  242,  182,   12,  242,  182,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  242,  182,   12,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  206,  142,    8,  235,  179,   22,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  235,  196,   12,  207,  148,   24,  254,  254,  252, 
 254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  254,  254,  252,  254,  254,  252,  244,  244,  244,  254,  254,  252,  244,  244, 
 244,  254,  254,  252,  254,  254,  252,   12,   12,   12,    2,    2,    4,    2,    2,    4, 
  31,   22,    4,  182,  126,   10,  223,  165,    9,  242,  182,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  229,  172,    9,  223,  165,    9,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  179,  121,    7,  207,  148,    7,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  242,  182,   12,  242,  182,   12,  225,  180,   10,  218,  163,    9,  106,   75, 
   6,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252, 
 254,  254,  252,  244,  244,  244,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254, 
 254,  252,  212,  212,  212,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,   49,   35,    5,  182,  126,   10,  229,  172,    9,  242,  182,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  235,  179,   22,  215,  150,   13,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  199,  138,    8,  223,  165,    9,  242,  182,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  236,  180,   11,  223,  165,    9,  164, 
 109,    5,   12,   12,   12,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254, 
 252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  254,  254,  252,  228,  228,  228, 
  12,   12,   12,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,   64,   44,    7,  182,  126,   10,  223,  165,    9,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  242,  182,   12,  242,  182,   12,  223, 
 165,    9,  206,  142,    8,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  199,  138,    8,  223,  165,    9,  242,  182,   12, 
 242,  182,   12,  242,  182,   12,  245,  189,   12,  242,  182,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  242,  182,   12,  218,  163,    9, 
 179,  121,    7,   41,   28,    4,    2,    2,    4,    2,    2,    4,   20,   20,   19,   52, 
  52,   52,   20,   20,   19,   12,   12,   12,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,   85,   59,    6,  185,  131,    9,  223,  165,    9,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189, 
  12,  245,  189,   12,  242,  182,   12,  242,  182,   12,  223,  165,    9,  199,  138,    8, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  192,  133,    7,  192,  133,    7,  215,  150, 
  13,  216,  156,    8,  223,  165,    9,  229,  172,    9,  229,  172,    9,  235,  179,   22, 
 242,  182,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  245, 
 189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  236,  180,   11,  209,  155, 
   9,  164,  109,    5,   91,   58,    5,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,   91,   58,    5,  182,  126,   10,  216,  156,    8,  242,  182,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  245,  189,   12,  242,  182,   12,  235, 
 179,   22,  223,  165,    9,  216,  156,    8,  192,  133,    7,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  144,   96,    7,  164, 
 109,    5,  179,  121,    7,  182,  126,   10,  192,  133,    7,  201,  142,    7,  206,  142, 
   8,  216,  156,    8,  223,  165,    9,  229,  172,    9,  235,  179,   22,  242,  182,   12, 
 245,  189,   12,  245,  189,   12,  245,  189,   12,  235,  179,   22,  223,  165,    9,  182, 
 126,   10,  151,   97,    5,   91,   58,    5,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,   83,   54,    6,  171,  114,    5,  199,  138,    8,  223,  165, 
   9,  242,  182,   12,  242,  182,   12,  242,  182,   12,  242,  182,   12,  229,  172,    9, 
 216,  156,    8,  199,  138,    8,  171,  114,    5,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  135,   88,    5,  151,   97,    5,  157,  106,    7,  164, 
 109,    5,  179,  121,    7,  179,  121,    7,  192,  133,    7,  207,  148,    7,  216,  156, 
   8,  223,  165,    9,  236,  180,   11,  236,  180,   11,  223,  165,    9,  201,  142,    7, 
 164,  109,    5,  131,   82,    4,   73,   48,    6,    2,    2,    4,    2,    2,    4,    2, 
   2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2, 
   4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4,    2,    2,    4, 
   2,    2,    4,    2,    2,    4,   73,   48,    6,  155,  102,    5,  182,  126,   10,  215, 
 150,   13,  229,  172,    9,  236,  180,   11,  229,  172,    9,  216,  156,    8,  207,  148, 
   7,  179,  121,    7,  144,   96,    7,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  108,   69,    5,  125,   83,    5,  144,   96,    7,  155,  102,    5,  179, 
 121,    7,  182,  126,   10,  193,  139,   10,  199,  138,    8,  182,  126,   10,  155,  102, 
   5,  131,   82,    4,   96,   62,    5,   20,   13,    4,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,   64,   44,    7,  143,   90,    4,  171,  114,    5, 
 182,  126,   10,  192,  133,    7,  201,  142,    7,  199,  138,    8,  179,  121,    7,  171, 
 114,    5,  116,   73,    4,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 101,   67,    7,  125,   83,    5,  131,   82,    4,  131,   82,    4,  131,   82,    4,  116, 
  73,    4,   91,   58,    5,   57,   38,   32,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,   83,   54,    6,  131,   82, 
   4,  157,  106,    7,  164,  109,    5,  164,  109,    5,  164,  109,    5,  135,   88,    5, 
  83,   54,    6,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,   73,   48,    6,   96,   62,    5,   91,   58,    5, 
  73,   48,    6,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,   64, 
  44,    7,   96,   62,    5,  108,   69,    5,  101,   67,    7,   96,   62,    5,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
 156,  156,  156,  156,  156,  156,  156,  156,  156,  156
};

